<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>{% block title %}Finite State Report Kit{% endblock %}</title>
    <link rel="stylesheet" href="/static/css/app.css">
    <script src="/static/vendor/htmx.min.js"></script>
    <script src="/static/vendor/alpine.min.js" defer></script>
</head>
<body hx-headers='{"X-FS-Session": "{{ nonce }}"}'>
    {% include "components/_nav.html" %}

    <main class="main-content">
        {% block content %}{% endblock %}
    </main>

    {% include "components/_toast.html" %}

    {% block scripts %}{% endblock %}
</body>
</html>
